/***************************************************************************
 * Header for the confirm dialog functions.
 * Copyright (C) 2004 Joe Wingbermuehle
 ***************************************************************************/

#ifndef CONFIRM_H
#define CONFIRM_H

struct ClientNode;

void InitializeDialogs();
void StartupDialogs();
void ShutdownDialogs();
void DestroyDialogs();

int ProcessDialogEvent(const XEvent *event);

void ShowConfirmDialog(struct ClientNode *np,
	void (*action)(struct ClientNode*), ...);

#endif

